
From: Alasdair G Kergon <agk@redhat.com>

Rename ctr to create etc.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/md/dm-emc.c           |   12 ++++++------
 25-akpm/drivers/md/dm-hw-handler.h    |    7 ++++---
 25-akpm/drivers/md/dm-mpath.c         |   12 ++++++------
 25-akpm/drivers/md/dm-path-selector.h |    4 ++--
 25-akpm/drivers/md/dm-round-robin.c   |    8 ++++----
 5 files changed, 22 insertions(+), 21 deletions(-)

diff -puN drivers/md/dm-emc.c~device-mapper-some-multipath-fn-renames drivers/md/dm-emc.c
--- 25/drivers/md/dm-emc.c~device-mapper-some-multipath-fn-renames	2005-02-16 13:47:47.000000000 -0800
+++ 25-akpm/drivers/md/dm-emc.c	2005-02-16 13:47:47.000000000 -0800
@@ -229,7 +229,7 @@ static struct emc_handler *alloc_emc_han
 	return h;
 }
 
-static int emc_ctr(struct hw_handler *hwh, unsigned argc, char **argv)
+static int emc_create(struct hw_handler *hwh, unsigned argc, char **argv)
 {
 	struct emc_handler *h;
 	unsigned hr, short_trespass;
@@ -276,7 +276,7 @@ static int emc_ctr(struct hw_handler *hw
 	return 0;
 }
 
-static void emc_dtr(struct hw_handler *hwh)
+static void emc_destroy(struct hw_handler *hwh)
 {
 	struct emc_handler *h = (struct emc_handler *) hwh->context;
 
@@ -284,7 +284,7 @@ static void emc_dtr(struct hw_handler *h
 	hwh->context = NULL;
 }
 
-static unsigned emc_err(struct hw_handler *hwh, struct bio *bio)
+static unsigned emc_error(struct hw_handler *hwh, struct bio *bio)
 {
 	/* FIXME: Patch from axboe still missing */
 #if 0
@@ -325,10 +325,10 @@ static unsigned emc_err(struct hw_handle
 static struct hw_handler_type emc_hwh = {
 	.name = "emc",
 	.module = THIS_MODULE,
-	.ctr = emc_ctr,
-	.dtr = emc_dtr,
+	.create = emc_create,
+	.destroy = emc_destroy,
 	.pg_init = emc_pg_init,
-	.err = emc_err,
+	.error = emc_error,
 };
 
 static int __init dm_emc_init(void)
diff -puN drivers/md/dm-hw-handler.h~device-mapper-some-multipath-fn-renames drivers/md/dm-hw-handler.h
--- 25/drivers/md/dm-hw-handler.h~device-mapper-some-multipath-fn-renames	2005-02-16 13:47:47.000000000 -0800
+++ 25-akpm/drivers/md/dm-hw-handler.h	2005-02-16 13:47:47.000000000 -0800
@@ -27,12 +27,13 @@ struct hw_handler_type {
 	char *name;
 	struct module *module;
 
-	int (*ctr) (struct hw_handler *handler, unsigned int argc, char **argv);
-	void (*dtr) (struct hw_handler *hwh);
+	int (*create) (struct hw_handler *handler, unsigned int argc,
+		       char **argv);
+	void (*destroy) (struct hw_handler *hwh);
 
 	void (*pg_init) (struct hw_handler *hwh, unsigned bypassed,
 			 struct path *path);
-	unsigned (*err) (struct hw_handler *hwh, struct bio *bio);
+	unsigned (*error) (struct hw_handler *hwh, struct bio *bio);
 	int (*status) (struct hw_handler *hwh, status_type_t type,
 		       char *result, unsigned int maxlen);
 };
diff -puN drivers/md/dm-mpath.c~device-mapper-some-multipath-fn-renames drivers/md/dm-mpath.c
--- 25/drivers/md/dm-mpath.c~device-mapper-some-multipath-fn-renames	2005-02-16 13:47:47.000000000 -0800
+++ 25-akpm/drivers/md/dm-mpath.c	2005-02-16 13:47:47.000000000 -0800
@@ -157,7 +157,7 @@ static void free_priority_group(struct p
 	struct path_selector *ps = &pg->ps;
 
 	if (ps->type) {
-		ps->type->dtr(ps);
+		ps->type->destroy(ps);
 		dm_put_path_selector(ps->type);
 	}
 
@@ -199,7 +199,7 @@ static void free_multipath(struct multip
 	}
 
 	if (hwh->type) {
-		hwh->type->dtr(hwh);
+		hwh->type->destroy(hwh);
 		dm_put_hw_handler(hwh->type);
 	}
 
@@ -495,7 +495,7 @@ static int parse_path_selector(struct ar
 	if (r)
 		return -EINVAL;
 
-	r = pst->ctr(&pg->ps, ps_argc, as->argv);
+	r = pst->create(&pg->ps, ps_argc, as->argv);
 	if (r) {
 		dm_put_path_selector(pst);
 		ti->error = ESTR("path selector constructor failed");
@@ -636,7 +636,7 @@ static int parse_hw_handler(struct arg_s
 		return -EINVAL;
 	}
 
-	r = hwht->ctr(&m->hw_handler, hw_argc - 1, as->argv);
+	r = hwht->create(&m->hw_handler, hw_argc - 1, as->argv);
 	if (r) {
 		dm_put_hw_handler(hwht);
 		ti->error = ESTR("hardware handler constructor failed");
@@ -996,8 +996,8 @@ static int do_end_io(struct multipath *m
 	}
 	spin_unlock(&m->lock);
 
-	if (hwh->type && hwh->type->err)
-		err_flags = hwh->type->err(hwh, bio);
+	if (hwh->type && hwh->type->error)
+		err_flags = hwh->type->error(hwh, bio);
 
 	if (mpio->pgpath) {
 		if (err_flags & MP_FAIL_PATH)
diff -puN drivers/md/dm-path-selector.h~device-mapper-some-multipath-fn-renames drivers/md/dm-path-selector.h
--- 25/drivers/md/dm-path-selector.h~device-mapper-some-multipath-fn-renames	2005-02-16 13:47:47.000000000 -0800
+++ 25-akpm/drivers/md/dm-path-selector.h	2005-02-16 13:47:47.000000000 -0800
@@ -37,8 +37,8 @@ struct path_selector_type {
 	/*
 	 * Constructs a path selector object, takes custom arguments
 	 */
-	int (*ctr) (struct path_selector *ps, unsigned argc, char **argv);
-	void (*dtr) (struct path_selector *ps);
+	int (*create) (struct path_selector *ps, unsigned argc, char **argv);
+	void (*destroy) (struct path_selector *ps);
 
 	/*
 	 * Add an opaque path object, along with some selector specific
diff -puN drivers/md/dm-round-robin.c~device-mapper-some-multipath-fn-renames drivers/md/dm-round-robin.c
--- 25/drivers/md/dm-round-robin.c~device-mapper-some-multipath-fn-renames	2005-02-16 13:47:47.000000000 -0800
+++ 25-akpm/drivers/md/dm-round-robin.c	2005-02-16 13:47:47.000000000 -0800
@@ -56,7 +56,7 @@ static struct selector *alloc_selector(v
 	return s;
 }
 
-static int rr_ctr(struct path_selector *ps, unsigned argc, char **argv)
+static int rr_create(struct path_selector *ps, unsigned argc, char **argv)
 {
 	struct selector *s;
 
@@ -68,7 +68,7 @@ static int rr_ctr(struct path_selector *
 	return 0;
 }
 
-static void rr_dtr(struct path_selector *ps)
+static void rr_destroy(struct path_selector *ps)
 {
 	struct selector *s = (struct selector *) ps->context;
 
@@ -177,8 +177,8 @@ static struct path_selector_type rr_ps =
 	.module = THIS_MODULE,
 	.table_args = 1,
 	.info_args = 0,
-	.ctr = rr_ctr,
-	.dtr = rr_dtr,
+	.create = rr_create,
+	.destroy = rr_destroy,
 	.status = rr_status,
 	.add_path = rr_add_path,
 	.fail_path = rr_fail_path,
_
